@@ -15,9 +15,12 @@
 # $Date: 2018-08-05 14:18:00 +0900 (週日, 05 八月 2018) $
 # $Revision: 11186 $
 
+import json
 import traceback
 import logging
 
+import requests
+
 from des.backends import ConfiguredEmailBackend as _ConfiguredEmailBackend
 from des.models import DynamicEmailConfiguration
 from django.conf import settings
@@ -27,22 +30,46 @@ from Iuppiter.Logging import createLogger
 
 logger = createLogger(__name__)
 
+NEWSKETTER_BLACKCONTACT_SEARCH_URL = "https://newsletter.nuwainfo.com/newsletters/newsletter/blackcontact/search/"
+
 class ConfiguredEmailBackend(_ConfiguredEmailBackend):
-    def send_messages(self, email_messages):
+    def send_messages(self, emailMessages):
+        # filter black contact 
+        emailMessagesAfterFilter = []
+        for message in emailMessages:
+            try:
+                payload = {
+                    "emails": message.to,
+                }
+                response = json.loads(
+                    requests.post(NEWSKETTER_BLACKCONTACT_SEARCH_URL, data=payload, 
+                    timeout=getattr(settings, "IUNO_EMAIL_BACKEND_SEARCH_BLACKCONTACT_TIMEOUT", 1)
+                ).text)
+                emails = [result['email'] for result in response.get("results", [])]
+                if emails:
+                    message.to = [email for email in message.to if not email in emails]
+                
+                if message.to:
+                    emailMessagesAfterFilter.append(message) 
+            except Exception as e:
+                logger.error(str(e))
+                emailMessagesAfterFilter.append(message)
+        emailMessages = emailMessagesAfterFilter
+        
         fromEmailList = []
         try:
             # 用 DynamicEmailConfiguration 寄信
             fromEmail = DynamicEmailConfiguration.objects.get().from_email
-            for message in email_messages:
+            for message in emailMessages:
                 fromEmailList.append(message.from_email)
                 message.from_email = fromEmail
 
             return super(
-                ConfiguredEmailBackend, self).send_messages(email_messages)
+                ConfiguredEmailBackend, self).send_messages(emailMessages)
         except Exception as e:
             # 不能用 DynamicEmailConfiguration 寄信，
             # 因此將 from_email 拿回來試試 SMTP 寄信
-            for i, message in enumerate(email_messages, 0):
+            for i, message in enumerate(emailMessages, 0):
                 message.from_email = fromEmailList[i]
             errMsg = (("Use dynamic email configuration to send email error: "
                        "%s\n%s\nUse SmtpEmailBackend to send email") % 
@@ -50,7 +77,7 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
             logger.warning(errMsg)
             smtp = SmtpEmailBackend()
             try:
-                r = smtp.send_messages(email_messages)
+                r = smtp.send_messages(emailMessages)
                 return r
             except Exception as e:
                 # 不能用 DynamicEmailConfiguration 寄信，
@@ -62,12 +89,12 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
                     (str(e), traceback.format_exc(), 
                      settings.DEFAULT_FROM_EMAIL))
                 logger.warning(errMsg)
-                for message in email_messages:
+                for message in emailMessages:
                     if not message.from_email == settings.DEFAULT_FROM_EMAIL:
                         message.from_email = settings.DEFAULT_FROM_EMAIL
                 
                 try:                
-                    r = smtp.send_messages(email_messages)
+                    r = smtp.send_messages(emailMessages)
                     return r
                 except Exception as e:
                     # 完全寄不了信
