@@ -46,7 +46,9 @@ def sendSMSAuthentication(request):
         
         result = verify(phone, template=temp, **count)
        
-        return JsonResponse(result)
+        response = JsonResponse(result)
+        response["Access-Control-Allow-Origin"] = "*"
+        return response
     raise Http404()
 
 @csrf_exempt    
@@ -73,5 +75,7 @@ def callAPISMS(request):
                 "error_msg": "permission denied",
             }
             
-        return JsonResponse(result)
+        response = JsonResponse(result)
+        response["Access-Control-Allow-Origin"] = "*"
+        return response
     raise Http404()
\ No newline at end of file
