@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12811 2021-03-24 12:13:54Z Casey $
+# $Id: __init__.py 12829 2021-04-03 03:09:45Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-03-24 20:13:54 +0800 (Wed, 24 Mar 2021) $
-# $Revision: 12811 $
+# $Date: 2021-04-03 11:09:45 +0800 (Sat, 03 Apr 2021) $
+# $Revision: 12829 $
 
 import os
 import sys
@@ -218,11 +218,6 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
 def attachURLs(settings, urlpatterns):
     from django.conf.urls import include, url
 
-    from .views import (
-        SignupView, LoginView, ConfirmEmailView, ChangePasswordView, LogoutView,
-        PasswordResetView, PasswordResetTokenView, SettingsView, DeleteView
-    )
-
     urlpatterns += (
         url(r'accounts/', include('Iuno.member.urls')),
     )
